function [profile, profile_unscaled, ro_est, h, Tmod, S] = scidarResultsnewgen(parameters, reg, filename, filename2);

% Modified Generalised SCIDAR Processing.  Scaling is performed on the T
% matrix and not on the calculated autocovariance, using the normalisation
% term extracted by deconvolution.  
%
% Inputs:   parameters  -   A vector containing values for 
%                           [zenith, binary_sep, m_diff, dr, scidar_defocus]
%                           where: zenith         - angle from the vertical (degrees)
%                                  binary_sep     - separation of binary star
%                                                   components (arcsecs)
%                                  m_diff         - magnitude difference of binary
%                                                   star components
%                                  dr             - pupil plane sampling (m)
%                                  scidar_defocus - amount of defocus beneath 
%                                                   telescope (km)
%           reg         -   Regularisation parameter value (between 0 and 1)
%           filename    -   Name of MATLAB file containing covariance data
%           filename2   -   Name of MATLAB file containing normalisation term
%   
% Outputs:  profile     -   Estimated Cn2 profile (m^(-2/3))
%           ro          -   Estimated ro value (m)
%
% Usage:    [profile, ro] = scidarResultsnewgen([10, 15, 1, 0.01, 2.5], 0.1, 'run20_auto', 'run20_norm');
%
% Rachel Johnston, 21/1/2002

% Preliminaries
zenith = parameters(1);
binary_sep = parameters(2);
m_diff = parameters(3);
dr = parameters(4);
scidar_defocus = parameters(5);
wavelength = 500e-9;		

secz = 1/cos(zenith*pi/180); 		
thi = binary_sep/((3600*180)/pi);
alpha = 10^(m_diff/2.5);
dh = 1*(dr/(thi*secz));

h1 = dh/2;                  % First altitude sample (m)
h_max = 25e3;               % Maximum range for calculations (m)
ns_h = ceil(h_max/dh);      % No. of altitude samples
if ns_h > 128
    ns_h  = 128;
    h_max = dh*ns_h;
end
sprintf(' Maximum height attainable is %5.2f meters',h_max);

h = h1:dh:ns_h*dh-h1;       % Altitude sample values (m)
r1=dr/2;
ns_r = ns_h ;               % No. of radius samples
r_max = thi*max(h)*secz ;   % Maximum radius corresponding to TRUE max height
r = r1:dr:ns_r*dr-r1;       % Radius sample values (m)

% Average data and autocorrelation
load(filename) 
load(filename2)

% Extracting autocorrelation slice
disp('Extracting covariance slice');
[S, binary_pos] = autoslicegen_2001(raw, ns_h, h, scidar_defocus, dr, zenith, binary_sep, m_diff);
%binary_pos

nrm_dim = max(size(nrm_new));
scale = max(max(nrm_new));
nrm_new = nrm_new/scale;
S = S.*(S>0);
S = S/(scale*alpha);

offset = thi*secz*scidar_defocus*1000;
offset = round(offset/dr);
nrm_new2 = zeros(256);
nrm_new2(129-nrm_dim/2:129+nrm_dim/2-1,129-nrm_dim/2+offset:129+nrm_dim/2-1+offset) = nrm_new;

% Generating the kernel (Scaled T matrix in this case)
[Tfull] = tmatrix(zenith, binary_sep, r, h, wavelength);
%[Tfull] = genTmat2001_2(zenith, binary_sep, r, h, scidar_defocus);
weight_temp = nrm_new2(129,129:256);
weight = zeros(size(Tfull));
[Trows, Tcols] = size(Tfull);
for i = 1:Tcols
   weight(:,i) = weight_temp(1:Trows)';
end  
Tmod = Tfull.*weight;

% The inversion
[profile, error] = scicongradqp(Tmod, S', zeros(size(h')), reg, max(size(S)));
%profile = profile.*(profile>0);
profile_unscaled = profile;
%profile = profile*1e-10*dh*secz^(11/6); %wrong
%zenith profile in m^1/3 units:
profile = profile*1e-12/secz;
Cn2_est = trapz(profile);
k = 2*pi/wavelength;
%ro_est = (0.423*(k^2)*secz*Cn2_est)^(-3/5);
ro_est = (0.423*(k^2)*Cn2_est)^(-3/5);
      disp('Processing complete');
    